@@ -2,8 +2,7 @@
 #define __TP_STREAM_ENGINE_SESSION_H__
 
 #include <glib-object.h>
-
-#include "stream.h"
+#include <telepathy-glib/media-interfaces.h>
 
 G_BEGIN_DECLS
 
@@ -29,10 +28,12 @@ G_BEGIN_DECLS
   (G_TYPE_INSTANCE_GET_CLASS ((obj), \
   TP_STREAM_ENGINE_TYPE_SESSION, TpStreamEngineSessionClass))
 
+typedef struct _TpStreamEngineSessionPrivate TpStreamEngineSessionPrivate;
+
 typedef struct {
   GObject parent;
 
-  GPtrArray *streams;
+  TpStreamEngineSessionPrivate *priv;
 } TpStreamEngineSession;
 
 typedef struct {
@@ -41,12 +42,10 @@ typedef struct {
 
 GType tp_stream_engine_session_get_type (void);
 
-TpStreamEngineSession* tp_stream_engine_session_new (void);
-gboolean tp_stream_engine_session_go (
-  TpStreamEngineSession *self, const gchar *bus_name,
-  const gchar *connection_path, const gchar *session_handler_path,
-  const gchar *channel_path, const gchar *type,
-  TpStreamEngineStreamProperties *props);
+TpStreamEngineSession *
+tp_stream_engine_session_new (TpMediaSessionHandler *proxy,
+                              const gchar *session_type,
+                              GError **error);
 
 G_END_DECLS
 
